@@ -8,17 +8,12 @@ import types
 def authenticator(handler, registry):
 
     def auth_request(request):
+
+        ignore_routes = ['static']
         #print(request.registry)
         response = None
-
         logged_in_user = request.session.get('logged_in_user', None)
 
-        protected_routes = []
-        routes = DBSession.query(RoutePermission.route_name).distinct().all()
-
-        for R in routes:
-            protected_routes.append(R[0])
-
         #print(protected_routes)
         matched_routename = None
 
@@ -32,20 +27,25 @@ def authenticator(handler, registry):
                 matched_routename = R['name']
                 break
 
+        if matched_routename and matched_routename in ignore_routes:
+            return handler(request)
+
+        protected_routes = []
+        routes = DBSession.query(RoutePermission.route_name).distinct().all()
+
+        for R in routes:
+            protected_routes.append(R[0])
+
         # Check routes from protected routes here.
         if matched_routename and matched_routename in protected_routes:
-            # first check if there is any static permission given and if yes then validate routes against that permission
-            user_permissions = []
-            if request.session.get('auth_static_permission', None):
-                user_permissions.append(request.session.get('auth_static_permission', None))
-            else:
-                if not logged_in_user:
-                    return HTTPForbidden()
+            if not logged_in_user:
+                return HTTPForbidden()
 
-                # get user permissions
-                UPs = DBSession.query(UserPermission.permission).filter_by(user_id=logged_in_user).all()
-                for UP in UPs:
-                    user_permissions.append(UP[0])
+            # get user permissions
+            user_permissions = []
+            UPs = DBSession.query(UserPermission.permission).filter_by(user_id=logged_in_user).all()
+            for UP in UPs:
+                user_permissions.append(UP[0])
 
             # get route permissions for the current route
             # match if there are any common permissions and check for all matching request methods
@@ -54,6 +54,7 @@ def authenticator(handler, registry):
                                             or_(RoutePermission.method == 'ALL',
                                                 RoutePermission.method == request.method)).filter(
                                             RoutePermission.permission.in_(user_permissions)).scalar()
+            #print("Has permission: %s" % str(has_permission))
 
             if has_permission > 0:
                 return handler(request)
